==> skymeter-1.1.2.tar.gz: skymeter/skymeter.pl <==
#!/usr/bin/env perl

# Skymeter script V1.1.2
# Geschreven door Thomas Langewouters
# Deze software valt onder de GNU Public License.
# ----------------------------------------------------

use strict;

my $debug = 0;

# skymeter.secrets bevat:
#	user uw_gebruikersnaam
#	pass uw_paswoord
#	cookiefile keep

# haal user, passwoord, en instellingen uit de configfile
my $login;
my $password;
my $keep_cookiefile;
my $cookiefile;

open(INFILE,  "/etc/skymeter.secrets")   or die "Can't open secrets file: $!";
while (<INFILE>) {     # assigns each line in turn to $_ 
	if ($_ =~ /user (.*)/) { $login = $1; }
	if ($_ =~ /pass (.*)/) { $password = $1}
	if ($_ =~ /cookiefile keep/) { $keep_cookiefile = 1}
}
close (INFILE);

if ($debug)
{
	print "login: -$login-, password -$password-\n";
}

if (! $login || ! $password)
{
	die "geen username of paswoord opgegeven\n";
}


$cookiefile = "/tmp/skymeter.cookie";

sub curl_get_url
{
	my $url = shift; 
	my $command = "curl -k -s -L -b $cookiefile -c $cookiefile $url";
	return `$command`;
}

sub curl_post_url
{
	my $url = shift; my $postdata = shift;
	my $command ="curl -k -s -L -c $cookiefile -b $cookiefile -d \"$postdata\" $url";
	return `$command`;
}

my $webpage;
print "Volumemeter opvragen... ";
$webpage =  curl_get_url("https://e-care.skynet.be/App/ConTime/index.cfm?fuseaction=VolumeMeter");

if ($webpage =~ /verzoeken wij u uw identiteit te bevestigen/) {
	# moeten we nog inloggen
	print "Inloggen... ";
	my $postdata="form_login=$login&form_password=$password&Langue_Id=2&fuseaction=CheckLoginConnection";
	$webpage = curl_post_url("https://e-care.skynet.be/Login/index.cfm", $postdata);

	if ($webpage =~ /verzoeken wij u uw identiteit te bevestigen/)
	{
		die "Authenticatie MISLUKT!!!\n";			
	}
	else
	{
		print "Authenticatie geslaagd!\n";
	}

	print "Volumemeter opvragen... \n";
	$webpage = curl_get_url("https://e-care.skynet.be/App/ConTime/index.cfm?fuseaction=VolumeMeter");

}
else
{
	print "Authenticatie geslaagd!\n";
}

if ($debug) {
	open(OUTFILE, ">webpage.txt") or die "Can't open webpage.txt: $!";
	print OUTFILE $webpage;
}

$webpage =~ /Gebruikt volume voor deze maand <font class="thirdlevel">(\d*\.*\d*) Gb<\/font> van de beschikbare (\d+) Gigabyte.<\/font><BR>/;
my $basis_used = $1;
my $basis_total = $2;

$webpage =~ /Gebruikt Extra Volume <font class="thirdlevel">(\d*\.*\d*) Gb<\/font> van de beschikbare (\d+) beschikbare Gigabyte <BR>/;
my $volumepack_used = $1;
my $volumepack_total = $2;

$webpage =~ /U heeft nog recht op  <font class="thirdlevel">(\d*)<\/font> niet gebruikt/;
my $volumepack_left = $1; 

print "Basisvolume [$basis_used / $basis_total] \n";
print "Lopende volumepack: [$volumepack_used / $volumepack_total]\n";

if ($volumepack_left != "0")
{
	print "U hebt nog $volumepack_left volumepacks buiten het lopende.\n";
}

if (! $keep_cookiefile) {
	print `rm $cookiefile`;
}

==> skymeter-1.1.4.tar.gz: skymeter/skymeter.pl <==
#!/usr/bin/env perl

# Skymeter script V1.1.4
# Geschreven door Thomas Langewouters
# Deze software valt onder de GNU Public License.
# ----------------------------------------------------

use strict;

# zet $debug = 1 bij het debuggen....
my $debug = 0;

# skymeter.secrets bevat:
#	user uw_gebruikersnaam
#	pass uw_paswoord
#	cookiefile keep
# /etc/skymeter.secrets zou omwille van veiligheidsredenen
# alleen leesbaar mogen zijn door root.

# haal user, passwoord, en instellingen uit de configfile
my $login;
my $password;
my $keep_cookiefile;
my $cookiefile;

open(INFILE,  "/etc/skymeter.secrets")   or die "Can't open secrets file: $!";
while (<INFILE>) {     # assigns each line in turn to $_ 
	if ($_ =~ /user (.*)/) { $login = $1; }
	if ($_ =~ /pass (.*)/) { $password = $1}
	if ($_ =~ /cookiefile keep/) { $keep_cookiefile = 1}
}
close (INFILE);

if ($debug)
{
	print "login: -$login-, password -$password-\n";
}

if (! $login || ! $password)
{
	die "geen username of paswoord opgegeven\n";
}


$cookiefile = "/tmp/skymeter.cookie";

sub curl_get_url
{
	my $url = shift; 
	my $command = "curl -k -s -L -b $cookiefile -c $cookiefile $url";
	return `$command`;
}

sub curl_post_url
{
	my $url = shift; my $postdata = shift;
	my $command ="curl -k -s -L -c $cookiefile -b $cookiefile -d \"$postdata\" $url";
	return `$command`;
}

my $webpage;
print "Volumemeter opvragen... ";
$webpage =  curl_get_url("https://e-care.skynet.be/App/ConTime/index.cfm?fuseaction=VolumeMeter");

if ($webpage =~ /verzoeken wij u uw identiteit te bevestigen/) {
	# moeten we nog inloggen
	print "Inloggen... ";
	my $postdata="form_login=$login&form_password=$password&Langue_Id=2&fuseaction=CheckLoginConnection";
	$webpage = curl_post_url("https://e-care.skynet.be/Login/index.cfm", $postdata);

	if ($webpage =~ /verzoeken wij u uw identiteit te bevestigen/)
	{
		die "Authenticatie MISLUKT!!!\n";			
	}
	else
	{
		print "Authenticatie geslaagd!\n";
	}

	print "Volumemeter opvragen... \n";
	$webpage = curl_get_url("https://e-care.skynet.be/App/ConTime/index.cfm?fuseaction=VolumeMeter");

}
else
{
	print "Authenticatie geslaagd!\n";
}

if ($debug) {
	open(OUTFILE, ">webpage.txt") or die "Can't open webpage.txt: $!";
	print OUTFILE $webpage;
}

$webpage =~ /Gebruikt volume voor deze maand <font class="thirdlevel">   (\d*\.*\d*) GB<\/font> van de beschikbare (\d+) GB/;
    
my $basis_used = $1;
my $basis_total = $2;

$webpage =~ /Gebruikt Extra Volume <font class="thirdlevel">    (\d*\.*\d*) GB<\/font> van de beschikbare (\d+) GB/;
my $volumepack_used = $1;
my $volumepack_total = $2;

if ($basis_used / $basis_total == 1) 
{
	print "Volledig basisvollume gebruikt \n";
	if ($webpage =~ /Huidig Volume Pack :/) 
	{
		print "Lopende volumepack: [$volumepack_used / $volumepack_total]\n";
	}

} 
else
{
	print "Basisvolume [$basis_used / $basis_total] \n";
}

if (! $keep_cookiefile) {
	print `rm $cookiefile`;
}
